local addon = CreateFrame("FRAME")
local overlayVisible = false


SLASH_HARMONIOUS1 = "/harmonious"
SLASH_HARMONY1 = "/harmony"


SlashCmdList["HARMONIOUS"] = function(params)
  addon:SlashCommand("/harmonious", params)
end


SlashCmdList["HARMONY"] = function(params)
  addon:SlashCommand("/harmony", params)
end


function addon:SlashCommand(command, params)
  local params = {string.split(" ", params)}
  local validCommand = false

  if params[1] and params[1]:lower() == "invert" then
    if params[2] and params[2]:lower() == "true" then
      validCommand = true
      invertOverlay = true
      print("|cFFFFA891Harmonious: |cFF89BABEinvert |cFFFFFFFF= |cFF89BABEtrue")
    elseif params[2] and params[2]:lower() == "false" then
      validCommand = true
      invertOverlay = false
      print("|cFFFFA891Harmonious: |cFF89BABEinvert |cFFFFFFFF= |cFF89BABEfalse")
    end
  end

  if not validCommand then
    print("|cFFFFA891Harmonious Usage: |cFF89BABE" .. command .. " invert |cFFFFFFFF<|cFF89BABEtrue|cFFFFFFFF|||cFF89BABEfalse|cFFFFFFFF>")
    print("|cFFFFA891Current: |cFFFFFFFF" .. (invertOverlay and "true" or "false") .. " |cFFFFA891Default: |cFFFFFFFFtrue")
  end
end


function addon:HandleRegistration()
  local currentSpec = GetSpecialization()
  local specId = select(1, GetSpecializationInfo(currentSpec))

  if specId == 105 then
    addon:RegisterEvent("UNIT_AURA")
    addon:RegisterEvent("PLAYER_REGEN_DISABLED")
    addon:RegisterEvent("PLAYER_REGEN_ENABLED")
  else
    addon:UnregisterEvent("UNIT_AURA")
    addon:UnregisterEvent("PLAYER_REGEN_DISABLED")
    addon:UnregisterEvent("PLAYER_REGEN_ENABLED")
  end
end


function addon:HasHarmony()
  local id = select(11, UnitAura("Player", "Harmony"))
  return id and true
end


function addon:ShowOverlay()
  if not overlayVisible then
    overlayVisible = true
    SpellActivationOverlay_ShowOverlay(SpellActivationOverlayFrame, 100977, "TEXTURES/SpellActivationOverlays/Serendipity.blp", "TOP", 1, 255, 255, 255, false, false)
    PlaySoundFile("Sound/SPELLS/Spell_EssenceofYulon_Cast_05.ogg")
  end
end


function addon:HideOverlay()
  SpellActivationOverlay_HideOverlays(SpellActivationOverlayFrame, 100977)
  overlayVisible = false
end


addon:SetScript("OnEvent", function(self, event, ...)
  if event == "ADDON_LOADED" then
    addon:HandleRegistration()
    if not invertOverlay then
      invertOverlay = true
    end

  elseif event == "PLAYER_TALENT_UPDATE" then
    self:HandleRegistration()

  elseif event == "PLAYER_REGEN_DISABLED" then
    if invertOverlay and not self:HasHarmony() then
      self:ShowOverlay()
    end

  elseif event == "PLAYER_REGEN_ENABLED" then
    if invertOverlay then
      self:HideOverlay()
    end

  elseif event == "UNIT_AURA" then
    if (invertOverlay and not self:HasHarmony() and UnitAffectingCombat("Player")) or (not invertOverlay and self:HasHarmony()) then
      self:ShowOverlay()
    else
      self:HideOverlay()
    end
  end
end)


addon:RegisterEvent("ADDON_LOADED")
addon:RegisterEvent("PLAYER_TALENT_UPDATE")
